PALM-meteo: palmmeteo.vinterp.VInterpFortranThread Class Reference

PALM-meteo

Public Member Functions | Public Attributes | List of all members
palmmeteo.vinterp.VInterpFortranThread Class Reference

## Public Member Functions
def | __init__ (self, variables, indices, zsource, ztarget, zinterp)
def | __call__ (self)
def | put (self, out)

## Public Attributes
| indices
| ztarget
| linear
| ain
| zsource

## Constructor & Destructor Documentation

## ◆ __init__()

def palmmeteo.vinterp.VInterpFortranThread.__init__ | ( |  | self,
|  |  | variables,
|  |  | indices,
|  |  | zsource,
|  |  | ztarget,
|  |  | zinterp
| ) |  |

## Member Function Documentation

## ◆ __call__()

def palmmeteo.vinterp.VInterpFortranThread.__call__ | ( |  | self | ) |

## ◆ put()

def palmmeteo.vinterp.VInterpFortranThread.put | ( |  | self,
|  |  | out
| ) |  |

    Write results to global array

## Member Data Documentation

## ◆ ain

palmmeteo.vinterp.VInterpFortranThread.ain

## ◆ indices

palmmeteo.vinterp.VInterpFortranThread.indices

## ◆ linear

palmmeteo.vinterp.VInterpFortranThread.linear

## ◆ zsource

palmmeteo.vinterp.VInterpFortranThread.zsource

## ◆ ztarget

palmmeteo.vinterp.VInterpFortranThread.ztarget

The documentation for this class was generated from the following file:

- palmmeteo/vinterp.py